lcvtoolbox.vision.geometry.primitives.pose\_rpy.PoseRPY
=======================================================

.. currentmodule:: lcvtoolbox.vision.geometry.primitives.pose_rpy

.. autoclass:: PoseRPY
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~PoseRPY.__init__
      ~PoseRPY.apply_to_vector
      ~PoseRPY.compose
      ~PoseRPY.copy
      ~PoseRPY.distance_to
      ~PoseRPY.from_degrees
      ~PoseRPY.from_list
      ~PoseRPY.from_numpy
      ~PoseRPY.from_transformation_matrix
      ~PoseRPY.identity
      ~PoseRPY.interpolate
      ~PoseRPY.inverse
      ~PoseRPY.is_close
      ~PoseRPY.random
      ~PoseRPY.relative_to
      ~PoseRPY.to_degrees
      ~PoseRPY.to_list
      ~PoseRPY.to_numpy
      ~PoseRPY.to_pose_quaternion
      ~PoseRPY.to_transformation_matrix
      ~PoseRPY.transform_point
      ~PoseRPY.transform_points
      ~PoseRPY.transform_vector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PoseRPY.orientation
      ~PoseRPY.pitch
      ~PoseRPY.position
      ~PoseRPY.roll
      ~PoseRPY.rotation_matrix
      ~PoseRPY.x
      ~PoseRPY.x_axis
      ~PoseRPY.y
      ~PoseRPY.y_axis
      ~PoseRPY.yaw
      ~PoseRPY.z
      ~PoseRPY.z_axis
   
   